@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with lava-scheduler-tool.  If not, see <http://www.gnu.org/licenses/>.
 
+import xmlrpclib
 
 from lava_tool.authtoken import AuthenticatingServerProxy, KeyringAuthBackend
-from lava_tool.interface import Command
+from lava_tool.interface import Command, LavaCommandError
 from lava_tool.commands import ExperimentalCommandMixIn
 
 
@@ -39,7 +40,12 @@ class submit_job(ExperimentalCommandMixIn, Command):
             self.args.SERVER, auth_backend=KeyringAuthBackend())
         with open(self.args.JSON_FILE, 'rb') as stream:
             command_text = stream.read()
-        print "submitted as job id:", server.scheduler.submit_job(command_text)
+        try:
+            job_id = server.scheduler.submit_job(command_text)
+        except xmlrpclib.Fault, e:
+            raise LavaCommandError(str(e))
+        else:
+            print "submitted as job id:", job_id
 
 
 class cancel_job(ExperimentalCommandMixIn, Command):
